#!/bin/sh
#
# BugSeeker for Java 2 Demo Startup Script
# ============================================================================
# For Linux, Solaris, Unix
#
# Please customize this script by following the five simple configuration
# steps listed below
# ----------------------------------------------------------------------------

# Step 1: 
# =======
#   Specify the JAVA_HOME for this script. JAVA_HOME should refer to the
#   home location where your system's Java Development Kit is installed
#   For instance, the supplied example assumes the JDK is installed at
#   /usr/java 
# ----------------------------------------------------------------------------

#JAVA_HOME=/usr/java
#JAVA_HOME=/usr/j2se		# Solaris JDK 1.3
JAVA_HOME=/usr/local/linux-jdk1.3.0				# FreeBSD

# Step 2: 
# =======
#   Next, ensure the BUGSEEKER2_HOME for this script points to the
#   installation home directory where Bugseeker was installed on your 
#   system.
# ----------------------------------------------------------------------------

#BUGSEEKER2_HOME=/usr/local/bugseeker2demo
BUGSEEKER2_HOME=/usr/local/bugseeker1.0.2			# FreeBSD

# Step 3:
# =======
#   JPDA configuration. JPDA needs to be properly installed and configured
#   before you can run BugSeeker. There are two things that need to be done
#   in this step: one, JPDA class libraries need to be added to the CLASSPATH;
#   two, JPDA native libraries need to be accessible from the LD_LIBRARY_PATH.
#
#   Linux:
#       All Linux J2SE SDK versions (Sun, IBM) have JPDA bundled with their 
#       distributions however the location of the JPDA files is not identical.
#
#           Sun         (Sun Linux JDK 1.2.2, JDK 1.3 Final)
#           IBM         (IBM Linux JDK 1.3 Final)
#
#       CLASSPATH:
#           ${JAVA_HOME}/lib/jpda.jar   (Sun 1.2)
#           ${JAVA_HOME}/lib/tools.jar  (Sun 1.3, IBM)
#
#       LD_LIBRARY_PATH:
#           ${JAVA_HOME}/lib/i386       (Sun)
#           ${JAVA_HOME}/jre/bin        (IBM)
#
#       Note: Although not related to BugSeeker startup, Sun JDK 1.3 users 
#             MUST always supply the -classic JVM option in their Project 
#             Properties Dialog | Launch Tab | Java Virtual Machine Options
#             textfield otherwise BugSeeker will hang when you start debugging.
#
#   Solaris:
#       Unlike Linux SDK distributions, Solaris JDK 1.2 users must separately 
#       download and install the JPDA. Solaris JDK 1.3 do not need to download
#       the JPDA separately because it is already bundled with this release.
#       To download the JPDA, goto:
#
#           http://java.sun.com/products/jpda/
#
#       Having installed JPDA, you should now add "jpda1.0/lib/jpda.jar" to
#       your CLASSPATH and "jpda1.0/lib/sparc" sub-dir to your LD_LIBRARY_PATH
#       
#   Generic Unix:
#       You need to find the location of where files libjdwp.so and 
#       libdt_socket.so is in your JDK distribution and add this location to
#       your LD_LIBRARY_PATH. You also need to locate the com.sun.jdi.* class 
#       libraries (often found in either jpda.jar or tools.jar of your SDK 
#       distribution) and add that to your CLASSPATH.
#
# Uncomment and edit the below script variables as appropriate to the JDK
# you will be running BugSeeker on. The examples below assume you are using 
# Sun Linux SDK 1.3
# ----------------------------------------------------------------------------

CLASSPATH=${CLASSPATH}:${JAVA_HOME}/lib/tools.jar		# Sun 1.3, IBM
#CLASSPATH=${CLASSPATH}:${JAVA_HOME}/lib/jpda.jar		# Sun 1.2

LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${JAVA_HOME}/lib/i386	# Sun
#LD_LIBRARY_PATH=${JAVA_HOME}/jre/bin				# IBM


# STEP 4:
# =======
# If you are using J2SE SDK 1.2.1 or below, you will need to launch
# BugSeeker using the "oldjava" command instead of "java". "oldjava"
# works around a system classloader/custom look and feel bug that exists
# only in SDK 1.2.1 and below. If you are using SDK 1.2.2 and above, you
# can safely use the "java" command
# ----------------------------------------------------------------------------

JAVA_EXE="java"
#JAVA_EXE="oldjava"


# STEP 5:
# =======
# BugSeeker has problems with Linux's HotSpot engine in Sun J2SE SDK 1.3
# use the -classic JVM option to disable hotspot (eg. JVM_ARGS="-classic ...")
#
# Solaris JDK 1.3 users should not supply the -classic option because this
# JDK release only comes with the HotSpot engine so supply -classic will
# result in an error
# ----------------------------------------------------------------------------

JVM_ARGS="-classic -ms16M -mx256M"		# Linux
#JVM_ARGS="-ms16M -mx256M"			# Solaris


# ----------------------------------------------------------------------------

export JAVA_HOME
export BUGSEEKER2_HOME
export LD_LIBRARY_PATH

MAIN_CLASS_NAME="bugseeker2.Main"


while [ $# -gt 0 ]; do
  ARGS="$ARGS $1"
  shift
done

OLDCP=$CLASSPATH
CLASSPATH=$BUGSEEKER2_HOME/lib/bugseeker2demo.jar

# Append old classpath to current classpath
if [ ! -z "$OLDCP" ]; then
    CLASSPATH=${CLASSPATH}:$OLDCP
fi
export CLASSPATH

# Available Look & Feel Color Themes:
#
# "Default", "Bubbles", "Convergence", "Golden_Poppy", "Lollipop",
# "Lollipop_3", "Lollipop_4", "Lollipop_5", "Rio_Azul", "Roswell", 
# "Sunny"

exec ${JAVA_HOME}/bin/${JAVA_EXE} $JVM_ARGS $MAIN_CLASS_NAME -theme "Convergence" $ARGS
